@@ -58,6 +58,12 @@ int MTX_DLL_API kt_get_v_pixel_height(KaxTrackEntry &track);
 #if !defined(EBML_ID_LENGTH)
 #define EBML_ID_LENGTH(id)  id.Length
 #endif
+#if !defined(EBML_CLASS_CONTEXT)
+#define EBML_CLASS_CONTEXT(ref) ref::ClassInfos.Context
+#endif
+#if !defined(EBML_CLASS_CALLBACK)
+#define EBML_CLASS_CALLBACK(ref)   ref::ClassInfos
+#endif
 #if !defined(EBML_CONTEXT)
 #define EBML_CONTEXT(e)  e->Generic().Context
 #endif
@@ -76,12 +82,6 @@ int MTX_DLL_API kt_get_v_pixel_height(KaxTrackEntry &track);
 #if !defined(EBML_SEM_UNIQUE)
 #define EBML_SEM_UNIQUE(s)  (s).Unique
 #endif
-#if !defined(EBML_SEM_INFO)
-#define EBML_SEM_INFO(s)  (s).GetCallbacks
-#endif
-#if !defined(EBML_SEM_ID)
-#define EBML_SEM_ID(s)    (s).GetCallbacks.GlobalId
-#endif
 #if !defined(EBML_SEM_CONTEXT)
 #define EBML_SEM_CONTEXT(s) (s).GetCallbacks.Context
 #endif
@@ -91,6 +91,18 @@ int MTX_DLL_API kt_get_v_pixel_height(KaxTrackEntry &track);
 #if !defined(EBML_CTX_SIZE)
 #define EBML_CTX_SIZE(c) (c).Size
 #endif
+#if !defined(EBML_CTX_IDX)
+#define EBML_CTX_IDX(c,i)   (c).MyTable[(i)]
+#endif
+#if !defined(EBML_CTX_IDX_INFO)
+#define EBML_CTX_IDX_INFO(c,i) (c).MyTable[(i)].GetCallbacks
+#endif
+#if !defined(EBML_CTX_IDX_ID)
+#define EBML_CTX_IDX_ID(c,i)   (c).MyTable[(i)].GetCallbacks.GlobalId
+#endif
+#if !defined(INVALID_FILEPOS_T)
+#define INVALID_FILEPOS_T 0
+#endif
 
 #define FINDFIRST(p, c)   (static_cast<c *>(((EbmlMaster *)p)->FindFirstElt(EBML_INFO(c), false)))
 #define FINDNEXT(p, c, e) (static_cast<c *>(((EbmlMaster *)p)->FindNextElt(*e, false)))
