@@ -36,7 +36,7 @@ public:
   virtual int get_progress();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, int64_t size);
+  static int probe_file(mm_io_c *io, uint64_t size);
 };
 
 #endif // __R_IVF_H
