@@ -77,6 +77,7 @@
 #include "output/p_vobbtn.h"
 #include "output/p_vobsub.h"
 #include "output/p_vorbis.h"
+#include "output/p_vc1.h"
 #include "output/p_vp8.h"
 #include "output/p_wavpack.h"
 
@@ -233,12 +234,6 @@ kax_reader_c::packets_available() {
   return 1;
 }
 
-kax_track_t *
-kax_reader_c::new_kax_track() {
-  m_tracks.push_back(kax_track_cptr(new kax_track_t));
-  return m_tracks.back().get_object();
-}
-
 kax_track_t *
 kax_reader_c::find_track_by_num(uint64_t n,
                                 kax_track_t *c) {
@@ -444,7 +439,7 @@ kax_reader_c::verify_mscomp_video_track(kax_track_t *t) {
 
   if (t->v_width != u) {
     if (verbose)
-      mxwarn(boost::format(Y("matroska_reader: (MS compatibility mode, track %1%) Matrosa says video width is %2%, but the BITMAPINFOHEADER says %3%.\n"))
+      mxwarn(boost::format(Y("matroska_reader: (MS compatibility mode, track %1%) Matroska says video width is %2%, but the BITMAPINFOHEADER says %3%.\n"))
              % t->tnum % t->v_width % u);
     if (0 == t->v_width)
       t->v_width = u;
@@ -453,7 +448,7 @@ kax_reader_c::verify_mscomp_video_track(kax_track_t *t) {
   u = get_uint32_le(&bih->bi_height);
   if (t->v_height != u) {
     if (verbose)
-      mxwarn(boost::format(Y("matroska_reader: (MS compatibility mode, track %1%) Matrosa video height is %2%, but the BITMAPINFOHEADER says %3%.\n"))
+      mxwarn(boost::format(Y("matroska_reader: (MS compatibility mode, track %1%) Matroska says video height is %2%, but the BITMAPINFOHEADER says %3%.\n"))
              % t->tnum % t->v_height % u);
     if (0 == t->v_height)
       t->v_height = u;
@@ -918,8 +913,8 @@ kax_reader_c::read_headers_info_writing_app(KaxWritingApp *&km_writing_app) {
 }
 
 void
-kax_reader_c::read_headers_track_audio(kax_track_t *&track,
-                                       KaxTrackAudio *&ktaudio) {
+kax_reader_c::read_headers_track_audio(kax_track_t *track,
+                                       KaxTrackAudio *ktaudio) {
   mxverb(2, "matroska_reader: |  + Audio track\n");
 
   KaxAudioSamplingFreq *ka_sfreq = FINDFIRST(ktaudio, KaxAudioSamplingFreq);
@@ -950,8 +945,8 @@ kax_reader_c::read_headers_track_audio(kax_track_t *&track,
 }
 
 void
-kax_reader_c::read_headers_track_video(kax_track_t *&track,
-                                       KaxTrackVideo *&ktvideo) {
+kax_reader_c::read_headers_track_video(kax_track_t *track,
+                                       KaxTrackVideo *ktvideo) {
   KaxVideoPixelWidth *kv_pwidth = FINDFIRST(ktvideo, KaxVideoPixelWidth);
   if (NULL != kv_pwidth) {
     track->v_width = uint64(*kv_pwidth);
@@ -1059,9 +1054,7 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
     // We actually found a track entry :) We're happy now.
     mxverb(2, "matroska_reader: | + a track...\n");
 
-    kax_track_t *track = new_kax_track();
-    if (NULL == track)
-      return;
+    kax_track_cptr track(new kax_track_t);
 
     KaxTrackNumber *ktnum = FINDFIRST(ktentry, KaxTrackNumber);
     if (NULL == ktnum)
@@ -1069,15 +1062,18 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
     mxverb(2, boost::format("matroska_reader: |  + Track number: %1%\n") % (int)uint8(*ktnum));
 
     track->tnum = uint8(*ktnum);
-    if (find_track_by_num(track->tnum, track) != NULL)
-      mxwarn(boost::format(Y("matroska_reader: |  + There's more than one track with the number %1%.\n")) % track->tnum);
+    if (find_track_by_num(track->tnum, track.get_object()) != NULL) {
+      mxverb(2, boost::format(Y("matroska_reader: |  + There's more than one track with the number %1%.\n")) % track->tnum);
+      ktentry = FINDNEXT(l1, KaxTrackEntry, ktentry);
+      continue;
+    }
 
     KaxTrackUID *ktuid = FINDFIRST(ktentry, KaxTrackUID);
     if (NULL == ktuid)
       mxerror(Y("matroska_reader: A track is missing its track UID.\n"));
     mxverb(2, boost::format("matroska_reader: |  + Track UID: %1%\n") % uint64(*ktuid));
     track->tuid = uint64(*ktuid);
-    if ((find_track_by_uid(track->tuid, track) != NULL) && (verbose > 1))
+    if ((find_track_by_uid(track->tuid, track.get_object()) != NULL) && (verbose > 1))
       mxwarn(boost::format(Y("matroska_reader: |  + There's more than one track with the UID %1%.\n")) % track->tnum);
 
     KaxTrackDefaultDuration *kdefdur = FINDFIRST(ktentry, KaxTrackDefaultDuration);
@@ -1099,11 +1095,11 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
 
     KaxTrackAudio *ktaudio = FINDFIRST(ktentry, KaxTrackAudio);
     if (NULL != ktaudio)
-      read_headers_track_audio(track, ktaudio);
+      read_headers_track_audio(track.get_object(), ktaudio);
 
     KaxTrackVideo *ktvideo = FINDFIRST(ktentry, KaxTrackVideo);
     if (NULL != ktvideo)
-      read_headers_track_video(track, ktvideo);
+      read_headers_track_video(track.get_object(), ktvideo);
 
     KaxCodecID *kcodecid = FINDFIRST(ktentry, KaxCodecID);
     if (NULL != kcodecid) {
@@ -1172,6 +1168,8 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
     }
 
     track->content_decoder.initialize(*ktentry);
+    m_tracks.push_back(track);
+
     ktentry = FINDNEXT(l1, KaxTrackEntry, ktentry);
   } // while (ktentry != NULL)
 
@@ -1180,8 +1178,8 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
 }
 
 void
-kax_reader_c::read_headers_seek_head(EbmlElement *&l0,
-                                     EbmlElement *&l1) {
+kax_reader_c::read_headers_seek_head(EbmlElement *l0,
+                                     EbmlElement *l1) {
   EbmlElement *el;
 
   KaxSeekHead &seek_head = *static_cast<KaxSeekHead *>(l1);
@@ -1322,7 +1320,7 @@ kax_reader_c::read_headers() {
     foreach(int64_t position, m_deferred_l1_positions[dl1t_tracks])
       read_headers_tracks(m_in.get_object(), l0, position);
 
-    if (!m_ti.m_no_attachments) {
+    if (!m_ti.m_attach_mode_list.none()) {
       foreach(int64_t position, m_deferred_l1_positions[dl1t_attachments])
         handle_attachments(m_in.get_object(), l0, position);
     }
@@ -1479,6 +1477,10 @@ kax_reader_c::create_video_packetizer(kax_track_t *t,
       t->handle_packetizer_pixel_dimensions();
       t->handle_packetizer_default_duration();
 
+    } else if ((t->codec_id == MKV_V_MSCOMP) && vc1::is_fourcc(t->v_fourcc)) {
+      mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the VC1 video output module.\n"));
+      set_track_packetizer(t, new vc1_video_packetizer_c(this, nti));
+
     } else {
       mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the video output module.\n"));
       set_track_packetizer(t, new video_packetizer_c(this, nti, t->codec_id.c_str(), t->v_frate, t->v_width, t->v_height));
@@ -2304,19 +2306,19 @@ kax_reader_c::identify() {
 
     if (track->ms_compat)
       info += std::string(", ") +
-        (  track->type        == 'v'    ? track->v_fourcc
-         : track->a_formattag == 0x0001 ? "PCM"
-         : track->a_formattag == 0x0003 ? "PCM"
-         : track->a_formattag == 0x0055 ? "MP3"
-         : track->a_formattag == 0x2000 ? "AC3"
-         :                                   Y("unknown"));
+        (  track->type        == 'v'    ? std::string(track->v_fourcc)
+         : track->a_formattag == 0x0001 ? std::string("PCM")
+         : track->a_formattag == 0x0003 ? std::string("PCM")
+         : track->a_formattag == 0x0055 ? std::string("MP3")
+         : track->a_formattag == 0x2000 ? std::string("AC3")
+         :                                (boost::format(Y("unknown, format tag 0x%|1$04x|")) % track->a_formattag).str());
 
     id_result_track(track->tnum,
                       track->type == 'v' ? ID_RESULT_TRACK_VIDEO
                     : track->type == 'a' ? ID_RESULT_TRACK_AUDIO
                     : track->type == 'b' ? ID_RESULT_TRACK_BUTTONS
                     : track->type == 's' ? ID_RESULT_TRACK_SUBTITLES
-                    :                          Y("unknown"),
+                    :                      Y("unknown"),
                     info, verbose_info);
   }
 
