@@ -74,6 +74,7 @@
 #include "common/version.h"
 #include "common/xml/element_mapping.h"
 #include "input/r_aac.h"
+#include "input/r_aac_adif.h"
 #include "input/r_ac3.h"
 #include "input/r_asf.h"
 #include "input/r_avc.h"
@@ -84,6 +85,7 @@
 #include "input/r_dts.h"
 #include "input/r_flac.h"
 #include "input/r_flv.h"
+#include "input/r_hdsub.h"
 #include "input/r_ivf.h"
 #include "input/r_matroska.h"
 #include "input/r_mp3.h"
@@ -185,6 +187,8 @@ int g_split_max_num_files                   = 65535;
 
 append_mode_e g_append_mode                 = APPEND_MODE_FILE_BASED;
 
+bool g_stereo_mode_used                     = false;
+
 std::string g_default_language              = "und";
 
 bitvalue_cptr g_seguid_link_previous;
@@ -212,6 +216,8 @@ static int s_display_files_done           = 0;
 static int s_display_path_length          = 1;
 static generic_reader_c *s_display_reader = NULL;
 
+static EbmlHead *s_head                   = NULL;
+
 /** \brief Add a segment family UID to the list if it doesn't exist already.
 
   \param family This segment family element is converted to a 128 bit
@@ -232,6 +238,13 @@ family_uids_c::add_family_uid(const KaxSegmentFamily &family) {
   return true;
 }
 
+std::ostream &
+operator<<(std::ostream &str,
+           const append_spec_t &spec) {
+  str << spec.src_file_id << ":" << spec.src_track_id << ":" << spec.dst_file_id << ":" << spec.dst_track_id;
+  return str;
+}
+
 /** \brief Fix the file after mkvmerge has been interrupted
 
    On Unix like systems mkvmerge will install a signal handler. On \c SIGUSR1
@@ -309,12 +322,16 @@ get_file_type(filelist_t &file) {
 
   file_type_e type = FILE_TYPE_IS_UNKNOWN;
   // File types that can be detected unambiguously but are not supported
-  if (asf_reader_c::probe_file(io, size))
+  if (aac_adif_reader_c::probe_file(io, size))
+    type = FILE_TYPE_AAC;
+  else if (asf_reader_c::probe_file(io, size))
     type = FILE_TYPE_ASF;
   else if (cdxa_reader_c::probe_file(io, size))
     type = FILE_TYPE_CDXA;
   else if (flv_reader_c::probe_file(io, size))
     type = FILE_TYPE_FLV;
+  else if (hdsub_reader_c::probe_file(io, size))
+    type = FILE_TYPE_HDSUB;
   // File types that can be detected unambiguously
   else if (avi_reader_c::probe_file(io, size))
     type = FILE_TYPE_AVI;
@@ -564,6 +581,29 @@ set_timecode_scale() {
   g_kax_cues->SetGlobalTimecodeScale((int64_t)g_timecode_scale);
 }
 
+static void
+render_ebml_head(mm_io_c *out) {
+  if (NULL == s_head)
+    s_head = new EbmlHead;
+
+  unsigned int doc_type_read_version                     = hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS) ? 1 : 2;
+
+  GetChildAs<EDocType, EbmlString>(*s_head)              = outputting_webm() ? "webm" : "matroska";
+
+  GetChildAs<EDocTypeVersion,     EbmlUInteger>(*s_head) = g_stereo_mode_used ? 3 : doc_type_read_version;
+  GetChildAs<EDocTypeReadVersion, EbmlUInteger>(*s_head) = doc_type_read_version;
+
+  s_head->Render(*out, true);
+}
+
+void
+rerender_ebml_head() {
+  mm_io_c *out = g_cluster_helper->get_output();
+  out->save_pos(s_head->GetElementPosition());
+  render_ebml_head(out);
+  out->restore_pos();
+}
+
 /** \brief Render the basic EBML and Matroska headers
 
    Renders the segment information and track headers. Also reserves
@@ -573,21 +613,7 @@ set_timecode_scale() {
 static void
 render_headers(mm_io_c *out) {
   try {
-    EbmlHead head;
-
-    bool first_file                                       = (1 == g_file_num);
-
-    GetChildAs<EDocType, EbmlString>(head)                = outputting_webm() ? "webm" : "matroska";
-    if (hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS)) {
-      GetChildAs<EDocTypeVersion,     EbmlUInteger>(head) = 1;
-      GetChildAs<EDocTypeReadVersion, EbmlUInteger>(head) = 1;
-
-    } else {
-      GetChildAs<EDocTypeVersion,     EbmlUInteger>(head) = 2;
-      GetChildAs<EDocTypeReadVersion, EbmlUInteger>(head) = 2;
-    }
-
-    head.Render(*out, true);
+    render_ebml_head(out);
 
     s_kax_infos = &GetChild<KaxInfo>(*g_kax_segment);
 
@@ -614,6 +640,8 @@ render_headers(mm_io_c *out) {
     if (!g_segment_title.empty())
       GetChildAs<KaxTitle, EbmlUnicodeString>(s_kax_infos)      = cstrutf8_to_UTFstring(g_segment_title.c_str());
 
+    bool first_file = (1 == g_file_num);
+
     // Generate the segment UIDs.
     if (!hack_engaged(ENGAGE_NO_VARIABLE_DATA)) {
       if (first_file) {
@@ -1573,6 +1601,9 @@ finish_file(bool last_file) {
   delete s_void_after_track_headers;
   if (NULL != g_kax_sh_cues)
     delete g_kax_sh_cues;
+  delete s_head;
+
+  s_head = NULL;
 
   return final_file_size;
 }
@@ -1683,7 +1714,9 @@ append_track(packetizer_t &ptzr,
   // But then again I don't expect that people will try to concatenate such
   // files if they've been split before.
   int64_t timecode_adjustment = dst_file.reader->m_max_timecode_seen;
-  if ((track_subtitle != ptzr.packetizer->get_track_type()) && (APPEND_MODE_FILE_BASED == g_append_mode))
+  if ((APPEND_MODE_FILE_BASED == g_append_mode)
+      && (   (track_subtitle != ptzr.packetizer->get_track_type())
+          || !dst_file.reader->is_simple_subtitle_container()))
     // Intentionally left empty.
     ;
 
