@@ -163,7 +163,7 @@ mmg_dialog::mmg_dialog()
 
   muxing_in_progress = false;
   last_open_dir      = wxEmptyString;
-  cmdline            = wxString::Format(wxU("\"%s\" -o \"%s\""), options.mkvmerge.c_str(), tc_output->GetValue().c_str());
+  cmdline            = wxString::Format(wxU("\"%s\" -o \"%s\""), options.mkvmerge_exe().c_str(), tc_output->GetValue().c_str());
 
   load_job_queue();
 
@@ -641,7 +641,7 @@ mmg_dialog::display_help(int id) {
     std::vector<wxString> potential_help_paths;
 
 #if defined(SYS_WINDOWS)
-    wxString installation_path = get_installation_dir();
+    wxString installation_path = wxU(get_installation_path());
     if (!installation_path.IsEmpty())
       potential_help_paths.push_back(installation_path + wxT("/doc"));
 
@@ -812,7 +812,7 @@ mmg_dialog::update_command_line() {
   unsigned int i;
 
   clargs.Clear();
-  clargs.Add(options.mkvmerge);
+  clargs.Add(options.mkvmerge_exe());
   clargs.Add(wxT("--output-charset"));
   clargs.Add(wxT("UTF-8"));
   clargs.Add(wxT("-o"));
@@ -1177,7 +1177,7 @@ mmg_dialog::update_command_line() {
     }
   }
 
-  cmdline = wxT("\"") + shell_escape(options.mkvmerge, true) + wxT("\" -o \"") + shell_escape(tc_output->GetValue()) + wxT("\" ");
+  cmdline = wxT("\"") + shell_escape(options.mkvmerge_exe(), true) + wxT("\" -o \"") + shell_escape(tc_output->GetValue()) + wxT("\" ");
 
   for (i = args_start; i < clargs.Count(); i++)
     cmdline += wxT(" \"") + shell_escape(clargs[i]) + wxT("\"");
@@ -1326,9 +1326,14 @@ mmg_dialog::set_output_maybe(const wxString &new_output) {
 
 wxString
 mmg_dialog::suggest_file_name_extension() {
-  bool has_video = false, has_audio = false, has_stereo_mode = false;
+  bool has_video = false, has_audio = false, has_stereo_mode = false, has_tracks = false;
 
   foreach(mmg_track_t *t, tracks) {
+    if (!t->enabled)
+      continue;
+
+    has_tracks = true;
+
     if (t->is_video()) {
       has_video = true;
       if (t->stereo_mode >= 2)
@@ -1342,7 +1347,14 @@ mmg_dialog::suggest_file_name_extension() {
        : has_stereo_mode                        ? wxU("mk3d")
        : has_video                              ? wxU("mkv")
        : has_audio                              ? wxU("mka")
-       :                                          wxU("mks");
+       : has_tracks                             ? wxU("mks")
+       :                                          wxU("mkv");
+}
+
+void
+mmg_dialog::update_output_file_name_extension() {
+  if (!tc_output->IsEmpty())
+    tc_output->SetValue(tc_output->GetValue().BeforeLast(wxT('.')) + wxT(".") + suggest_file_name_extension());
 }
 
 void
@@ -1591,25 +1603,6 @@ mmg_dialog::load_preferences() {
 
   options.init_popular_languages(s);
   options.validate();
-
-#if defined(SYS_WINDOWS)
-  // Check whether or not the mkvmerge executable path is still set to
-  // the default value "mkvmerge". If it is try getting the
-  // installation path from the registry and use that for a more
-  // precise location for mkvmerge.exe. Fall back to the old default
-  // value "mkvmerge" if all else fails.
-  if (options.mkvmerge == wxT("mkvmerge"))
-    options.mkvmerge.Empty();
-
-  if (options.mkvmerge.IsEmpty()) {
-    options.mkvmerge = get_installation_dir();
-    if (!options.mkvmerge.IsEmpty())
-      options.mkvmerge += wxT("\\mkvmerge.exe");
-  }
-
-  if (options.mkvmerge.IsEmpty())
-    options.mkvmerge = wxT("mkvmerge");
-#endif  // SYS_WINDOWS
 }
 
 void
@@ -1649,9 +1642,7 @@ mmg_dialog::set_on_top(bool on_top) {
 
 void
 mmg_dialog::handle_webm_mode(bool enabled) {
-  if (!tc_output->IsEmpty())
-    tc_output->SetValue(tc_output->GetValue().BeforeLast(wxT('.')) + wxT(".") + suggest_file_name_extension());
-
+  update_output_file_name_extension();
   input_page->handle_webm_mode(enabled);
   global_page->handle_webm_mode(enabled);
 }
@@ -1811,7 +1802,7 @@ mmg_dialog::query_mkvmerge_capabilities() {
   int result;
 
   wxLogMessage(Z("Querying mkvmerge's capabilities"));
-  tmp = wxT("\"") + options.mkvmerge + wxT("\" --capabilities");
+  tmp = wxT("\"") + options.mkvmerge_exe() + wxT("\" --capabilities");
 #if defined(SYS_WINDOWS)
   result = wxExecute(tmp, output);
 #else
